
#include <Wire.h>
#include <Adafruit_MMA8451.h>
#include <Adafruit_Sensor.h>
#include "touch1.h"

Adafruit_MMA8451 mma = Adafruit_MMA8451();

const int ledPin =  9;      // the number of the LED pin

void setup(void) {
  Serial.begin(9600);
  if (! mma.begin()) {
    Serial.println("Couldnt start");
    while (1);
  }
  Serial.println("MMA8451 found!");

  // initialize the LED pin as an output:
  pinMode(ledPin, OUTPUT);
  mma.setRange(MMA8451_RANGE_2_G);
  
  Serial.print("Range = "); Serial.print(2 << mma.getRange());  
  Serial.println("G");
  
}

void loop() {
  // Read the 'raw' data in 14-bit counts
  mma.read();
  double data[11] = {0};
  /* Get a new sensor event */ 
  sensors_event_t event; 
  mma.getEvent(&event);

  /* Display the results (acceleration is measured in m/s^2) */
  Serial.print("X: \t"); Serial.print(event.acceleration.x); Serial.print("\t");
  data[0] = event.acceleration.x;
  Serial.print("Y: \t"); Serial.print(event.acceleration.y); Serial.print("\t");
  data[1] = event.acceleration.y;
  Serial.print("Z: \t"); Serial.print(event.acceleration.z); Serial.print("\t");
  data[2] = event.acceleration.z;
  Serial.println("m/s^2 ");
  
  /* Get the orientation of the sensor */
  uint8_t o = mma.getOrientation();
  
  switch (o) {
    case MMA8451_PL_PUF: 
      Serial.println("Portrait Up Front");
      data[3] = 0;
      data[4] = 0;
      data[5] = 0;
      data[6] = 0;
      data[7] = 0;
      data[8] = 0;
      data[9] = 0;
      data[10] = 1;
      break;
    case MMA8451_PL_PUB: 
      Serial.println("Portrait Up Back");
      data[3] = 0;
      data[4] = 0;
      data[5] = 0;
      data[6] = 0;
      data[7] = 0;
      data[8] = 0;
      data[9] = 1;
      data[10] = 0;
      break;    
    case MMA8451_PL_PDF: 
      Serial.println("Portrait Down Front");
      data[3] = 0;
      data[4] = 0;
      data[5] = 0;
      data[6] = 0;
      data[7] = 0;
      data[8] = 1;
      data[9] = 0;
      data[10] = 0;
      break;
    case MMA8451_PL_PDB: 
      Serial.println("Portrait Down Back");
      data[3] = 0;
      data[4] = 0;
      data[5] = 0;
      data[6] = 0;
      data[7] = 1;
      data[8] = 0;
      data[9] = 0;
      data[10] = 0;
      break;
    case MMA8451_PL_LRF: 
      Serial.println("Landscape Right Front");
      data[3] = 0;
      data[4] = 0;
      data[5] = 0;
      data[6] = 1;
      data[7] = 0;
      data[8] = 0;
      data[9] = 0;
      data[10] = 0;
      break;
    case MMA8451_PL_LRB: 
      Serial.println("Landscape Right Back");
      data[3] = 0;
      data[4] = 0;
      data[5] = 1;
      data[6] = 0;
      data[7] = 0;
      data[8] = 0;
      data[9] = 0;
      data[10] = 0;
      break;
    case MMA8451_PL_LLF: 
      Serial.println("Landscape Left Front");
      data[3] = 0;
      data[4] = 1;
      data[5] = 0;
      data[6] = 0;
      data[7] = 0;
      data[8] = 0;
      data[9] = 0;
      data[10] = 0;
      break;
    case MMA8451_PL_LLB: 
      Serial.println("Landscape Left Back");
      data[3] = 1;
      data[4] = 0;
      data[5] = 0;
      data[6] = 0;
      data[7] = 0;
      data[8] = 0;
      data[9] = 0;
      data[10] = 0;
      break;
    }
  for(int a = 0; a < 10; a++){
    float printval = data[a];
    Serial.println(printval);
  }
  switch (o) {
    case MMA8451_PL_PUB:
      classify(data);
      break;
    default:
      digitalWrite(ledPin, LOW);
      break;
  }
  delay(500);
  
}

void classify(double features[]) {
    Serial.print("Predicted class: ");
    Serial.println(predict(features));
    int state = predict(features);
    Serial.println(state);
    if (state == 1) {
    // turn LED on:
      Serial.println("LIGHTING!");
      digitalWrite(ledPin, HIGH);
    } else {
      // turn LED off:
      digitalWrite(ledPin, LOW);
    }
}
